@@ -69,11 +69,11 @@ class Q_AUTOTEST_EXPORT QQmlConnections : public QObject, public QQmlParserStatu
 
     Q_INTERFACES(QQmlParserStatus)
     Q_PROPERTY(QObject *target READ target WRITE setTarget NOTIFY targetChanged)
-    Q_REVISION(1) Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled NOTIFY enabledChanged)
+    Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled NOTIFY enabledChanged REVISION 3)
     Q_PROPERTY(bool ignoreUnknownSignals READ ignoreUnknownSignals WRITE setIgnoreUnknownSignals)
 
 public:
-    QQmlConnections(QObject *parent=0);
+    QQmlConnections(QObject *parent=nullptr);
     ~QQmlConnections();
 
     QObject *target() const;
@@ -87,19 +87,23 @@ public:
 
 Q_SIGNALS:
     void targetChanged();
-    Q_REVISION(1) void enabledChanged();
+    Q_REVISION(3) void enabledChanged();
 
 private:
     void connectSignals();
-    void classBegin();
-    void componentComplete();
+    void connectSignalsToMethods();
+    void connectSignalsToBindings();
+
+    void classBegin() override;
+    void componentComplete() override;
 };
 
+// TODO: Drop this class as soon as we can
 class QQmlConnectionsParser : public QQmlCustomParser
 {
 public:
-    virtual void verifyBindings(const QV4::CompiledData::Unit *qmlUnit, const QList<const QV4::CompiledData::Binding *> &props);
-    virtual void applyBindings(QObject *object, QQmlCompiledData *cdata, const QList<const QV4::CompiledData::Binding *> &bindings);
+    void verifyBindings(const QQmlRefPointer<QV4::ExecutableCompilationUnit> &compilationUnit, const QList<const QV4::CompiledData::Binding *> &props) override;
+    void applyBindings(QObject *object, const QQmlRefPointer<QV4::ExecutableCompilationUnit> &compilationUnit, const QList<const QV4::CompiledData::Binding *> &bindings) override;
 };
 
 
