@@ -58,7 +58,7 @@
 #include <wtf/Vector.h>
 #include <assembler/MacroAssembler.h>
 
-#ifdef V4_ENABLE_JIT
+QT_REQUIRE_CONFIG(qml_jit);
 
 QT_BEGIN_NAMESPACE
 
@@ -320,14 +320,14 @@ public:
 
     void pushAligned(RegisterID reg)
     {
-        subPtr(TrustedImm32(PointerSize), StackPointerRegister);
+        subPtr(TrustedImm32(3 * PointerSize), StackPointerRegister);
         push(reg);
     }
 
     void popAligned(RegisterID reg)
     {
         pop(reg);
-        addPtr(TrustedImm32(PointerSize), StackPointerRegister);
+        addPtr(TrustedImm32(3 * PointerSize), StackPointerRegister);
     }
 };
 
@@ -449,7 +449,7 @@ public:
     // r6 is used by MacroAssemblerARMv7
     static const RegisterID JSStackFrameRegister     = JSC::ARMRegisters::r8;
     static const RegisterID CppStackFrameRegister    = JSC::ARMRegisters::r10;
-#if CPU(ARM_THUMB2) || defined(V4_BOOTSTRAP)
+#if CPU(ARM_THUMB2)
     static const RegisterID FramePointerRegister     = JSC::ARMRegisters::r7;
     static const RegisterID EngineRegister           = JSC::ARMRegisters::r11;
 #else // Thumbs down
@@ -587,7 +587,7 @@ public:
     Address loadCompilationUnitPtr(RegisterID target)
     {
         Address addr = loadFunctionPtr(target);
-        addr.offset = offsetof(QV4::Function, compilationUnit);
+        addr.offset = offsetof(QV4::FunctionData, compilationUnit);
         loadPtr(addr, target);
         return Address(target);
     }
@@ -619,11 +619,14 @@ public:
         for (Jump j : catchyJumps)
             j.link(this);
 
+        // We don't need to check for isInterrupted here because if that is set,
+        // then the first checkException() in any exception handler will find another "exception"
+        // and jump out of the exception handler.
         loadPtr(exceptionHandlerAddress(), ScratchRegister);
         Jump exitFunction = branchPtr(Equal, ScratchRegister, TrustedImmPtr(0));
+        loadUndefined();
         jump(ScratchRegister);
         exitFunction.link(this);
-        loadUndefined();
 
         if (functionExit.isSet())
             jump(functionExit);
@@ -633,6 +636,8 @@ public:
 
     void checkException()
     {
+        // This actually reads 4 bytes, starting at hasException.
+        // Therefore, it also reads the isInterrupted flag, and triggers an exception on that.
         addCatchyJump(
                     branch32(NotEqual,
                              Address(EngineRegister, offsetof(EngineBase, hasException)),
@@ -670,7 +675,8 @@ public:
 
     void addLabelForOffset(int offset)
     {
-        labelForOffset.insert(offset, label());
+        if (!labelForOffset.contains(offset))
+            labelForOffset.insert(offset, label());
     }
 
     void addJumpToOffset(const Jump &jump, int offset)
@@ -699,6 +705,7 @@ public:
     void passAddressAsArg(Address addr, int arg);
     void passCppFrameAsArg(int arg);
     void passInt32AsArg(int value, int arg);
+    void passPointerAsArg(void *ptr, int arg);
     void callRuntime(const char *functionName, const void *funcPtr);
     void callRuntimeUnchecked(const char *functionName, const void *funcPtr);
     void tailCallRuntime(const char *functionName, const void *funcPtr);
@@ -709,7 +716,6 @@ public:
 private:
     void passAccumulatorAsArg_internal(int arg, bool doPush);
     static Address argStackAddress(int arg);
-    static Address inArgStackAddress(int arg);
 
 private:
     const Value* constantTable;
@@ -734,6 +740,4 @@ private:
 
 QT_END_NAMESPACE
 
-#endif // V4_ENABLE_JIT
-
 #endif // QV4PLATFORMASSEMBLER_P_H
